==> owncloud-4.0.4.tgz: owncloud/core/l10n/gl.php <==
<?php $TRANSLATIONS = array(
"Application name not provided." => "Non se indicou o nome do aplicativo.",
"No category to add?" => "Sen categoría que engadir?",
"This category already exists: " => "Esta categoría xa existe: ",
"Owncloud password reset" => "Restablecemento do contrasinal de Owncloud",
"ownCloud password reset" => "Restablecer contrasinal de ownCloud",
"Use the following link to reset your password: {link}" => "Use a seguinte ligazón para restablecer o contrasinal: {link}",
"You will receive a link to reset your password via Email." => "Recibirá unha ligazón por correo electrónico para restablecer o contrasinal",
"Requested" => "Solicitado",
"Login failed!" => "Fallou a conexión.",
"Username" => "Nome de usuario",
"Request reset" => "Petición de restablecemento",
"Your password was reset" => "O contrasinal foi restablecido",
"To login page" => "A páxina de conexión",
"New password" => "Novo contrasinal",
"Reset password" => "Restablecer contrasinal",
"Personal" => "Persoal",
"Users" => "Usuarios",
"Apps" => "Aplicativos",
"Admin" => "Admin",
"Help" => "Axuda",
"Access forbidden" => "Acceso denegado",
"Cloud not found" => "Nube non atopada",
"Edit categories" => "Editar categorias",
"Add" => "Engadir",
"Create an <strong>admin account</strong>" => "Crear unha <strong>contra de administrador</strong>",
"Password" => "Contrasinal",
"Advanced" => "Avanzado",
"Data folder" => "Cartafol de datos",
"Configure the database" => "Configurar a base de datos",
"will be used" => "será utilizado",
"Database user" => "Usuario da base de datos",
"Database password" => "Contrasinal da base de datos",
"Database name" => "Nome da base de datos",
"Database host" => "Servidor da base de datos",
"Finish setup" => "Rematar configuración",
"web services under your control" => "servizos web baixo o seu control",
"Log out" => "Desconectar",
"Settings" => "Preferencias",
"Lost your password?" => "Perdeu o contrasinal?",
"remember" => "lembrar",
"Log in" => "Conectar",
"You are logged out." => "Está desconectado",
"prev" => "anterior",
"next" => "seguinte"
);

==> owncloud-4.5.7.tgz: owncloud/core/l10n/gl.php <==
<?php $TRANSLATIONS = array(
"Application name not provided." => "Non se indicou o nome do aplicativo.",
"No category to add?" => "Sen categoría que engadir?",
"This category already exists: " => "Esta categoría xa existe: ",
"Settings" => "Preferencias",
"January" => "Xaneiro",
"February" => "Febreiro",
"March" => "Marzo",
"April" => "Abril",
"May" => "Maio",
"June" => "Xuño",
"July" => "Xullo",
"August" => "Agosto",
"September" => "Setembro",
"October" => "Outubro",
"November" => "Novembro",
"December" => "Nadal",
"Cancel" => "Cancelar",
"No" => "Non",
"Yes" => "Si",
"Ok" => "Ok",
"No categories selected for deletion." => "Non hai categorías seleccionadas para eliminar.",
"Error" => "Erro",
"Password" => "Contrasinal",
"ownCloud password reset" => "Restablecer contrasinal de ownCloud",
"Use the following link to reset your password: {link}" => "Use a seguinte ligazón para restablecer o contrasinal: {link}",
"You will receive a link to reset your password via Email." => "Recibirá unha ligazón por correo electrónico para restablecer o contrasinal",
"Requested" => "Solicitado",
"Login failed!" => "Fallou a conexión.",
"Username" => "Nome de usuario",
"Request reset" => "Petición de restablecemento",
"Your password was reset" => "O contrasinal foi restablecido",
"To login page" => "A páxina de conexión",
"New password" => "Novo contrasinal",
"Reset password" => "Restablecer contrasinal",
"Personal" => "Persoal",
"Users" => "Usuarios",
"Apps" => "Aplicativos",
"Admin" => "Admin",
"Help" => "Axuda",
"Access forbidden" => "Acceso denegado",
"Cloud not found" => "Nube non atopada",
"Edit categories" => "Editar categorias",
"Add" => "Engadir",
"Create an <strong>admin account</strong>" => "Crear unha <strong>contra de administrador</strong>",
"Advanced" => "Avanzado",
"Data folder" => "Cartafol de datos",
"Configure the database" => "Configurar a base de datos",
"will be used" => "será utilizado",
"Database user" => "Usuario da base de datos",
"Database password" => "Contrasinal da base de datos",
"Database name" => "Nome da base de datos",
"Database host" => "Servidor da base de datos",
"Finish setup" => "Rematar configuración",
"web services under your control" => "servizos web baixo o seu control",
"Log out" => "Desconectar",
"Lost your password?" => "Perdeu o contrasinal?",
"remember" => "lembrar",
"Log in" => "Conectar",
"You are logged out." => "Está desconectado",
"prev" => "anterior",
"next" => "seguinte"
);
